[Xorg-commit] xc/programs/Xserver/hw/darwin/quartz/cr crScreen.m,1.1.4.1,1.1.4.2

Kaleb Keithley xorg-commit at pdx.freedesktop.org
Thu Dec 18 21:29:45 EET 2003


Committed by: kaleb

Update of /cvs/xorg/xc/programs/Xserver/hw/darwin/quartz/cr
In directory pdx:/home/kaleb/xorg/xc.XORG-CURRENT/programs/Xserver/hw/darwin/quartz/cr

Modified Files:
      Tag: XORG-CURRENT
	crScreen.m 
Log Message:
First pass at "Standard" Xinerama.
The sources for this came from Heather Lanigan's xinerama tree on 
Sourceforge.Net. 
No attempt has been made to handle previous, non-standard versions of 
the protocol. Nor has any attempt been made to preserve the ABI of 
previous versions -- that part will be added at a later time, and 
then probably only on systems that have nice object/linker semantics, 
e.g. ELF systems with weak symbols.



Index: crScreen.m
===================================================================
RCS file: /cvs/xorg/xc/programs/Xserver/hw/darwin/quartz/cr/crScreen.m,v
retrieving revision 1.1.4.1
retrieving revision 1.1.4.2
diff -u -d -r1.1.4.1 -r1.1.4.2
--- crScreen.m	6 Dec 2003 13:24:23 -0000	1.1.4.1
+++ crScreen.m	18 Dec 2003 19:29:13 -0000	1.1.4.2
@@ -1,3 +1,4 @@
+/* $XdotOrg$ */
 /*
  * Cocoa rootless implementation initialization
  */
@@ -27,7 +28,6 @@
  * holders shall not be used in advertising or otherwise to promote the sale,
  * use or other dealings in this Software without prior written authorization.
  */
-/* $XdotOrg$ */
 /* $XFree86: xc/programs/Xserver/hw/darwin/quartz/cr/crScreen.m,v 1.6 2003/11/27 01:59:53 torrey Exp $ */
 
 #include "quartzCommon.h"
@@ -40,7 +40,7 @@
 #include "quartzCursor.h"
 #include "rootless.h"
 #include "safeAlpha.h"
-#include "pseudoramiX.h"
+#include "pseudorama.h"
 #include "applewmExt.h"
 
 #include "regionstr.h"
@@ -59,8 +59,8 @@
  * CRDisplayInit
  *  Find all screens.
  *
  *  Multihead note: When rootless mode uses PseudoramiX, the
  *  X server only sees one screen; only PseudoramiX itself knows
  *  about all of the screens.
  */
 static void
@@ -68,10 +68,10 @@
 {
     ErrorF("Display mode: Rootless Quartz -- Cocoa implementation\n");
 
-    if (noPseudoramiXExtension) {
+    if (noPseudoramaExtension) {
         darwinScreensFound = [[NSScreen screens] count];
     } else {
-        darwinScreensFound = 1; // only PseudoramiX knows about the rest
+        darwinScreensFound = 1; // only Pseudorama knows about the rest
     }
 
     CRAppleWMInit();
@@ -89,7 +89,7 @@
     dfb->bitsPerPixel = CGDisplayBitsPerPixel(kCGDirectMainDisplay);
     dfb->colorBitsPerPixel = 3 * dfb->bitsPerComponent;
 
-    if (noPseudoramiXExtension) {
+    if (noPseudoramaExtension) {
         NSScreen *screen = [[NSScreen screens] objectAtIndex:index];
         NSRect frame = [screen frame];
 
@@ -133,7 +133,7 @@
         dfb->height = unionRect.size.height;
         dfb->pitch = (dfb->width) * (dfb->bitsPerPixel) / 8;
 
         // Tell PseudoramiX about the real screens.
         // InitOutput() will move the big screen to (0,0),
         // so compensate for that here.
         for (i = 0; i < [screens count]; i++) {
@@ -144,7 +144,7 @@
             // Skip this screen if it's a mirrored copy of an earlier screen.
             for (j = 0; j < i; j++) {
                 if (NSEqualRects(frame, [[screens objectAtIndex:j] frame])) {
-                    ErrorF("PseudoramiX screen %d is a mirror of screen %d.\n",
+                    ErrorF("Pseudorama screen %d is a mirror of screen %d.\n",
                            i, j);
                     break;
                 }
@@ -159,17 +159,17 @@
                 frame.size.height -= aquaMenuBarHeight;
             }
 
-            ErrorF("PseudoramiX screen %d added: %dx%d @ (%d,%d).\n", i,
+            ErrorF("Pseudorama screen %d added: %dx%d @ (%d,%d).\n", i,
                    (int)frame.size.width, (int)frame.size.height,
                    (int)frame.origin.x, (int)frame.origin.y);
 
             frame.origin.x -= unionRect.origin.x;
             frame.origin.y -= unionRect.origin.y;
 
-            ErrorF("PseudoramiX screen %d placed at X11 coordinate (%d,%d).\n",
+            ErrorF("Pseudorama screen %d placed at X11 coordinate (%d,%d).\n",
                    i, (int)frame.origin.x, (int)frame.origin.y);
 
-            PseudoramiXAddScreen(frame.origin.x, frame.origin.y,
+            PseudoramaAddScreen(frame.origin.x, frame.origin.y,
                                  frame.size.width, frame.size.height);
         }
     }
@@ -219,7 +219,7 @@
 
     // This X11 screen covers all CoreGraphics displays we just found.
     // If there's more than one CG display, then video mirroring is on
-    // or PseudoramiX is on.
+    // or Pseudorama is on.
     displayInfo->displayCount = allocatedDisplays;
     displayInfo->displayIDs = displays;
 
@@ -59,8 +59,8 @@
  *  Find all screens.
  *
- *  Multihead note: When rootless mode uses PseudoramiX, the
- *  X server only sees one screen; only PseudoramiX itself knows
+ *  Multihead note: When rootless mode uses Pseudorama, the
+ *  X server only sees one screen; only Pseudorama itself knows
  *  about all of the screens.
  */
@@ -133,7 +133,7 @@
         dfb->pitch = (dfb->width) * (dfb->bitsPerPixel) / 8;
 
-        // Tell PseudoramiX about the real screens.
+        // Tell Pseudorama about the real screens.
         // InitOutput() will move the big screen to (0,0),
         // so compensate for that here.





More information about the xorg-commit mailing list